@@ -11,7 +11,7 @@ def includeme(config):
 
     config.add_route(
         'clientlogs',
-        '/clientlogs/{logger_name:[\d\w\.]+}/{log_level:debug|info|warning|error|critical}',
+        '/clientlogs/{logger_name:[\d\w\.:]+}/{log_level:debug|info|warning|error|critical}',
         request_method='POST',
         )
     config.scan('pyramid_restlogging.views')
